@@ -1,7 +1,7 @@
 package slot;
 use strict;
 use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 require XSLoader;
 XSLoader::load('slot', $VERSION);
 1;
@@ -38,7 +38,7 @@ slot - global reactive state slots with optional watchers
 
 =head1 DESCRIPTION
 
-C<slot> provides fast, globally-shared named storage slots with XS performance.
+C<slot> provides fast, globally shared named storage slots.
 Slots are shared across all packages - importing the same slot name in different
 packages gives access to the same underlying value.
 
@@ -46,7 +46,7 @@ Key features:
 
 =over 4
 
-=item * B<Fast> - Custom ops, faster than raw hash access (~100M setter, ~65M getter)
+=item * B<Fast> - Custom ops
 
 =item * B<Global> - Slots are shared across packages by name
 
@@ -97,6 +97,38 @@ Register a callback that fires whenever the slot value changes.
 
 Returns a list of all defined slot names.
 
+=head1 THREAD SAFETY
+
+For thread-safe data sharing, store C<threads::shared> variables in slots:
+
+    use threads;
+    use threads::shared;
+    use slot qw(config);
+
+    # Create shared data and store in slot
+    my %shared :shared;
+    $shared{counter} = 0;
+    config(\%shared);
+
+    # Threads can now safely share data via the slot
+    my @threads = map {
+        threads->create(sub {
+            my $cfg = config();
+            lock(%$cfg);
+            $cfg->{counter}++;
+        });
+    } 1..10;
+
+    $_->join for @threads;
+    print config()->{counter};  # 10
+
+The slot provides the global accessor; C<threads::shared> provides the
+thread-safe storage.
+
+=head1 FORK BEHAVIOR
+
+After C<fork()>, child processes get a copy of slot values (copy-on-write).
+Changes in child processes do not affect the parent, and vice versa.
 
 =head1 BENCHMARK
 
@@ -119,10 +151,9 @@ bench.pl is included
 	slot       72793704/s       532%       445%        32%         --
 
 
-
 =head1 AUTHOR
 
-LNATION E<lt>email@lnation.orgE<gt>
+LNATION <email@lnation.org>
 
 =head1 LICENSE
 
